import os
from builtins import open as _open
from urllib.parse import urlparse
from urllib.request import url2pathname
from typing_extensions import Union

from gbox_sdk._types import NOT_GIVEN, NotGiven, FileTypes
from gbox_sdk._client import GboxClient
from gbox_sdk._response import BinaryAPIResponse
from gbox_sdk.types.v1.android_box import AndroidBox
from gbox_sdk.wrapper.box.android.types import ListAndroidApp
from gbox_sdk.types.v1.boxes.android_app import AndroidApp
from gbox_sdk.wrapper.box.android.app_operator import AndroidAppOperator
from gbox_sdk.types.v1.boxes.android_install_response import AndroidInstallResponse
from gbox_sdk.types.v1.boxes.android_list_app_response import AndroidListAppResponse


class AndroidAppManager:
    """
    Manager class for handling Android app operations within a box.

    Provides methods to install, uninstall, list, retrieve, close, and backup Android apps.

    Attributes:
        client (GboxClient): The API client used for communication.
        box (AndroidBox): The Android box data object.
    """

    def __init__(self, client: GboxClient, box: AndroidBox):
        """
        Initialize an AndroidAppManager instance.

        Args:
            client (GboxClient): The API client used for communication.
            box (AndroidBox): The Android box data object.
        """
        self.client = client
        self.box = box

    def install(
        self,
        *,
        apk: Union[str, FileTypes],
        open: Union[bool, NotGiven] = NOT_GIVEN,
    ) -> AndroidAppOperator:
        """
        Install an Android app on the box.

        Supports multiple APK input formats:
        - Local file path: "/path/to/app.apk"
        - File URL: "file:///path/to/app.apk"
        - HTTP URL: "https://example.com/app.apk"
        - File object or stream

        Args:
            apk: APK file or ZIP archive to install (max file size: 512MB).

              **Single APK mode (installMultiple: false):**

              - Upload a single APK file (e.g., app.apk)

              **Install-Multiple mode (installMultiple: true):**

              - Upload a ZIP archive containing multiple APK files
              - ZIP filename example: com.reddit.frontpage-gplay.zip
              - ZIP contents example:

              com.reddit.frontpage-gplay.zip
              └── com.reddit.frontpage-gplay/ (folder)
                ├── reddit-base.apk (base APK)
                ├── reddit-arm64.apk (architecture-specific)
                ├── reddit-en.apk (language pack)
                └── reddit-mdpi.apk (density-specific resources)

              This is commonly used for split APKs where different components are separated by
              architecture, language, or screen density.

            install_multiple: Whether to use 'adb install-multiple' command for installation. When true, uses
                install-multiple which is useful for split APKs or when installing multiple
                related packages. When false, uses standard 'adb install' command. Split APKs
                are commonly used for apps with different architecture variants, language packs,
                or modular components.

            open: Whether to open the app after installation. Will find and launch the launcher
                activity of the installed app. If there are multiple launcher activities, only
                one will be opened. If the installed APK has no launcher activity, this
                parameter will have no effect.

        Returns:
            AndroidAppOperator: Operator for the installed app.

        Examples:
            >>> box.app.install(apk="/path/to/app.apk")
            >>> box.app.install(apk="https://example.com/app.apk")
        """
        if isinstance(apk, str):
            if apk.startswith("file://"):
                # Handle file:// protocol
                parsed_url = urlparse(apk)
                file_path = url2pathname(parsed_url.path)
                if not os.path.exists(file_path):
                    raise FileNotFoundError(f"File {file_path} does not exist")
                with _open(file_path, "rb") as apk_file:
                    res = self.client.v1.boxes.android.install(box_id=self.box.id, apk=apk_file, open=open)
                    return self._install_res_to_operator(res)
            elif apk.startswith("http"):
                # Handle http/https URLs
                res = self.client.v1.boxes.android.install(box_id=self.box.id, apk=apk, open=open)
                return self._install_res_to_operator(res)
            else:
                # Handle local file paths
                if not os.path.exists(apk):
                    raise FileNotFoundError(f"File {apk} does not exist")
                with _open(apk, "rb") as apk_file:
                    res = self.client.v1.boxes.android.install(box_id=self.box.id, apk=apk_file, open=open)
                    return self._install_res_to_operator(res)

        # Handle file objects or other types
        res = self.client.v1.boxes.android.install(box_id=self.box.id, apk=apk, open=open)
        return self._install_res_to_operator(res)

    def uninstall(self, package_name: str, *, keep_data: Union[bool, NotGiven] = NOT_GIVEN) -> None:
        """
        Uninstall an Android app from the box.

        Args:
            package_name: The package name of the app to uninstall.

            keep_data: uninstalls the pkg while retaining the data/cache

        Examples:
            >>> box.app.uninstall("com.example.app")
            >>> box.app.uninstall(package_name="com.example.app", keep_data=True)
        """
        return self.client.v1.boxes.android.uninstall(package_name, box_id=self.box.id, keep_data=keep_data)

    def list(self) -> ListAndroidApp:
        """
        List all installed Android apps as operator objects.

        Returns:
            ListAndroidApp: Response containing app operator instances.

        Examples:
            >>> box.app.list()
        """
        res = self.client.v1.boxes.android.list_app(box_id=self.box.id)
        return ListAndroidApp(operators=[AndroidAppOperator(self.client, self.box, app) for app in res.data])

    def list_info(self) -> AndroidListAppResponse:
        """
        Get detailed information of all installed Android apps.

        Returns:
            AndroidListAppResponse: Response containing app information.

        Examples:
            >>> box.app.list_info()
        """
        return self.client.v1.boxes.android.list_app(box_id=self.box.id)

    def get(self, package_name: str) -> AndroidAppOperator:
        """
        Get an operator for a specific installed app.

        Args:
            package_name: The package name of the app.

        Returns:
            AndroidAppOperator: Operator for the specified app.

        Examples:
            >>> box.app.get("com.example.app")
        """
        res = self.client.v1.boxes.android.get_app(package_name, box_id=self.box.id)
        return AndroidAppOperator(self.client, self.box, res)

    def get_info(self, package_name: str) -> AndroidApp:
        """
        Get detailed information for a specific installed app.

        Args:
            package_name: The package name of the app.

        Returns:
            AndroidGetResponse: App information response.

        Examples:
            >>> box.app.get_info("com.example.app")
        """
        res = self.client.v1.boxes.android.get_app(package_name, box_id=self.box.id)
        return res

    def close_all(self) -> None:
        """
        Close all running Android apps on the box.

        Examples:
            >>> box.app.close_all()
        """
        return self.client.v1.boxes.android.close_all(box_id=self.box.id)

    def backup_all(self) -> BinaryAPIResponse:
        """
        Backup all installed Android apps on the box.

        Returns:
            BinaryAPIResponse: The backup response containing binary data.

        Examples:
            >>> box.app.backup_all()
        """
        return self.client.v1.boxes.android.backup_all(box_id=self.box.id)

    def _install_res_to_operator(self, res: AndroidInstallResponse) -> AndroidAppOperator:
        """
        Convert an install response to an AndroidAppOperator instance.

        Args:
            res (AndroidInstallResponse): The install response.

        Returns:
            AndroidAppOperator: Operator for the installed app.
        """
        activity = next((x for x in res.activities if x.is_launcher), None)
        if activity is None:
            raise ValueError("No launcher activity found")

        app = AndroidApp(
            packageName=res.package_name,
            activityName=activity.name,
            activityClassName=activity.class_name,
        )
        return AndroidAppOperator(self.client, self.box, app)



from typing import Union

from gbox_sdk._types import NOT_GIVEN, NotGiven
from gbox_sdk._client import GboxClient
from gbox_sdk._response import BinaryAPIResponse
from gbox_sdk.types.v1.android_box import AndroidBox
from gbox_sdk.types.v1.boxes.android_app import AndroidApp
from gbox_sdk.types.v1.boxes.android_list_activities_response import AndroidListActivitiesResponse


class AndroidAppOperator:
    """
    Operator class for managing a specific Android app within a box.

    Provides methods to open, restart, close, list activities, and backup the app.

    Attributes:
        client (GboxClient): The API client used for communication.
        box (AndroidBox): The Android box data object.
        data (AndroidApp): The app data object.
    """

    def __init__(self, client: GboxClient, box: AndroidBox, data: AndroidApp):
        """
        Initialize an AndroidAppOperator instance.

        Args:
            client (GboxClient): The API client used for communication.
            box (AndroidBox): The Android box data object.
            data (AndroidApp): The app data object.
        """
        self.client = client
        self.box = box
        self.data = data

    def open(self, activity_name: Union[str, NotGiven] = NOT_GIVEN) -> None:
        """
        Open the app, optionally specifying an activity name.

        Args:
            activity_name: Activity name, default is the main activity.

        Examples:
            >>> box.app.open()
            >>> box.app.open("com.example.app.MainActivity")
        """
        return self.client.v1.boxes.android.open(
            self.data.package_name, box_id=self.box.id, activity_name=activity_name
        )

    def restart(self, activity_name: Union[str, NotGiven] = NOT_GIVEN) -> None:
        """
        Restart the app, optionally specifying an activity name.

        Args:
            activity_name: Activity name, default is the main activity.

        Examples:
            >>> box.app.restart()
            >>> box.app.restart("com.example.app.MainActivity")
        """
        return self.client.v1.boxes.android.restart(
            self.data.package_name, box_id=self.box.id, activity_name=activity_name
        )

    def close(self) -> None:
        """
        Close the app.

        Examples:
            >>> box.app.close()
        """
        return self.client.v1.boxes.android.close(package_name=self.data.package_name, box_id=self.box.id)

    def list_activities(self) -> AndroidListActivitiesResponse:
        """
        List all activities of the app.

        Returns:
            AndroidListActivitiesResponse: The response containing the list of activities.

        Examples:
            >>> box.app.list_activities()
        """
        return self.client.v1.boxes.android.list_activities(package_name=self.data.package_name, box_id=self.box.id)

    def backup(self) -> BinaryAPIResponse:
        """
        Backup the app.

        Returns:
            BinaryAPIResponse: The backup response containing binary data.

        Examples:
            >>> box.app.backup()
        """
        return self.client.v1.boxes.android.backup(package_name=self.data.package_name, box_id=self.box.id)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from ...._utils import PropertyInfo
from .action_common_options_param import ActionCommonOptionsParam

__all__ = ["ActionScrollParams", "ScrollAdvanced", "ScrollSimple"]


class ScrollAdvanced(TypedDict, total=False):
    scroll_x: Required[Annotated[float, PropertyInfo(alias="scrollX")]]
    """Horizontal scroll amount.

    Positive values scroll content rightward (reveals content on the right),
    negative values scroll content leftward (reveals content on the left).
    """

    scroll_y: Required[Annotated[float, PropertyInfo(alias="scrollY")]]
    """Vertical scroll amount.

    Positive values scroll content downward (reveals content below), negative values
    scroll content upward (reveals content above).
    """

    x: Required[float]
    """X coordinate of the scroll position"""

    y: Required[float]
    """Y coordinate of the scroll position"""

    include_screenshot: Annotated[bool, PropertyInfo(alias="includeScreenshot")]
    """⚠️ DEPRECATED: Use `options.screenshot.phases` instead.

    This field will be ignored when `options.screenshot` is provided. Whether to
    include screenshots in the action response. If false, the screenshot object will
    still be returned but with empty URIs. Default is false.
    """

    options: ActionCommonOptionsParam
    """Action common options"""

    output_format: Annotated[Literal["base64", "storageKey"], PropertyInfo(alias="outputFormat")]
    """⚠️ DEPRECATED: Use `options.screenshot.outputFormat` instead.

    Type of the URI. default is base64. This field will be ignored when
    `options.screenshot` is provided.
    """

    presigned_expires_in: Annotated[str, PropertyInfo(alias="presignedExpiresIn")]
    """⚠️ DEPRECATED: Use `options.screenshot.presignedExpiresIn` instead.

    Presigned url expires in. Only takes effect when outputFormat is storageKey.
    This field will be ignored when `options.screenshot` is provided.

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 30m
    """

    screenshot_delay: Annotated[str, PropertyInfo(alias="screenshotDelay")]
    """⚠️ DEPRECATED: Use `options.screenshot.delay` instead.

    This field will be ignored when `options.screenshot` is provided.

    Delay after performing the action, before taking the final screenshot.

    Execution flow:

    1. Take screenshot before action
    2. Perform the action
    3. Wait for screenshotDelay (this parameter)
    4. Take screenshot after action

    Example: '500ms' means wait 500ms after the action before capturing the final
    screenshot.

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 500ms Maximum allowed: 30s
    """


class ScrollSimple(TypedDict, total=False):
    direction: Required[Literal["up", "down", "left", "right"]]
    """Direction to scroll.

    The scroll will be performed from the center of the screen towards this
    direction. 'up' scrolls content upward (reveals content below), 'down' scrolls
    content downward (reveals content above), 'left' scrolls content leftward
    (reveals content on the right), 'right' scrolls content rightward (reveals
    content on the left).
    """

    distance: Union[float, Literal["tiny", "short", "medium", "long"]]
    """Distance of the scroll.

    Can be either a number (in pixels) or a predefined enum value (tiny, short,
    medium, long). If not provided, the scroll will be performed from the center of
    the screen to the screen edge
    """

    duration: str
    """Duration of the scroll

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 500ms
    """

    include_screenshot: Annotated[bool, PropertyInfo(alias="includeScreenshot")]
    """⚠️ DEPRECATED: Use `options.screenshot.phases` instead.

    This field will be ignored when `options.screenshot` is provided. Whether to
    include screenshots in the action response. If false, the screenshot object will
    still be returned but with empty URIs. Default is false.
    """

    options: ActionCommonOptionsParam
    """Action common options"""

    output_format: Annotated[Literal["base64", "storageKey"], PropertyInfo(alias="outputFormat")]
    """⚠️ DEPRECATED: Use `options.screenshot.outputFormat` instead.

    Type of the URI. default is base64. This field will be ignored when
    `options.screenshot` is provided.
    """

    presigned_expires_in: Annotated[str, PropertyInfo(alias="presignedExpiresIn")]
    """⚠️ DEPRECATED: Use `options.screenshot.presignedExpiresIn` instead.

    Presigned url expires in. Only takes effect when outputFormat is storageKey.
    This field will be ignored when `options.screenshot` is provided.

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 30m
    """

    screenshot_delay: Annotated[str, PropertyInfo(alias="screenshotDelay")]
    """⚠️ DEPRECATED: Use `options.screenshot.delay` instead.

    This field will be ignored when `options.screenshot` is provided.

    Delay after performing the action, before taking the final screenshot.

    Execution flow:

    1. Take screenshot before action
    2. Perform the action
    3. Wait for screenshotDelay (this parameter)
    4. Take screenshot after action

    Example: '500ms' means wait 500ms after the action before capturing the final
    screenshot.

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 500ms Maximum allowed: 30s
    """


ActionScrollParams: TypeAlias = Union[ScrollAdvanced, ScrollSimple]



from typing import TYPE_CHECKING, List, Union
from typing_extensions import Required, Annotated, TypedDict

from gbox_sdk._utils._transform import PropertyInfo
from gbox_sdk.types.v1.boxes.android_install_params import InstallAndroidPkgByURL, InstallAndroidPkgByFile

# Forward references for type annotations
if TYPE_CHECKING:
    from gbox_sdk.wrapper.box.android.app_operator import AndroidAppOperator
    from gbox_sdk.wrapper.box.android.pkg_operator import AndroidPkgOperator


class InstallAndroidAppByLocalFile(TypedDict, total=False):
    apk: Required[str]


AndroidInstall = Union[InstallAndroidPkgByFile, InstallAndroidPkgByURL, InstallAndroidAppByLocalFile]


class ListAndroidApp:
    """Response type for listing Android apps as operators."""

    def __init__(self, operators: List["AndroidAppOperator"]):
        self.operators = operators


class ListAndroidPkg:
    """Response type for listing Android packages as operators."""

    def __init__(self, operators: List["AndroidPkgOperator"]):
        self.operators = operators


class AndroidUninstall(TypedDict, total=False):
    """Parameters for uninstalling an Android package (without box_id)."""

    keep_data: Annotated[bool, PropertyInfo(alias="keepData")]
    """uninstalls the pkg while retaining the data/cache"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from ...._utils import PropertyInfo
from .action_common_options_param import ActionCommonOptionsParam

__all__ = [
    "ActionSwipeParams",
    "SwipeSimple",
    "SwipeAdvanced",
    "SwipeAdvancedEnd",
    "SwipeAdvancedEndSwipePath",
    "SwipeAdvancedStart",
    "SwipeAdvancedStartSwipePath",
]


class SwipeSimple(TypedDict, total=False):
    direction: Required[Literal["up", "down", "left", "right", "upLeft", "upRight", "downLeft", "downRight"]]
    """Direction to swipe.

    The gesture will be performed from the center of the screen towards this
    direction.
    """

    distance: Union[float, Literal["tiny", "short", "medium", "long"]]
    """Distance of the swipe.

    Can be either a number (in pixels) or a predefined enum value (tiny, short,
    medium, long). If not provided, the swipe will be performed from the center of
    the screen to the screen edge
    """

    duration: str
    """Duration of the swipe

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 500ms
    """

    include_screenshot: Annotated[bool, PropertyInfo(alias="includeScreenshot")]
    """⚠️ DEPRECATED: Use `options.screenshot.phases` instead.

    This field will be ignored when `options.screenshot` is provided. Whether to
    include screenshots in the action response. If false, the screenshot object will
    still be returned but with empty URIs. Default is false.
    """

    location: str
    """Natural language description of the location where the swipe should originate.

    If not provided, the swipe will be performed from the center of the screen.
    """

    options: ActionCommonOptionsParam
    """Action common options"""

    output_format: Annotated[Literal["base64", "storageKey"], PropertyInfo(alias="outputFormat")]
    """⚠️ DEPRECATED: Use `options.screenshot.outputFormat` instead.

    Type of the URI. default is base64. This field will be ignored when
    `options.screenshot` is provided.
    """

    presigned_expires_in: Annotated[str, PropertyInfo(alias="presignedExpiresIn")]
    """⚠️ DEPRECATED: Use `options.screenshot.presignedExpiresIn` instead.

    Presigned url expires in. Only takes effect when outputFormat is storageKey.
    This field will be ignored when `options.screenshot` is provided.

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 30m
    """

    screenshot_delay: Annotated[str, PropertyInfo(alias="screenshotDelay")]
    """⚠️ DEPRECATED: Use `options.screenshot.delay` instead.

    This field will be ignored when `options.screenshot` is provided.

    Delay after performing the action, before taking the final screenshot.

    Execution flow:

    1. Take screenshot before action
    2. Perform the action
    3. Wait for screenshotDelay (this parameter)
    4. Take screenshot after action

    Example: '500ms' means wait 500ms after the action before capturing the final
    screenshot.

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 500ms Maximum allowed: 30s
    """


class SwipeAdvanced(TypedDict, total=False):
    end: Required[SwipeAdvancedEnd]
    """End point of the swipe path (coordinates or natural language)"""

    start: Required[SwipeAdvancedStart]
    """Start point of the swipe path (coordinates or natural language)"""

    duration: str
    """Duration of the swipe

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 500ms
    """

    include_screenshot: Annotated[bool, PropertyInfo(alias="includeScreenshot")]
    """⚠️ DEPRECATED: Use `options.screenshot.phases` instead.

    This field will be ignored when `options.screenshot` is provided. Whether to
    include screenshots in the action response. If false, the screenshot object will
    still be returned but with empty URIs. Default is false.
    """

    options: ActionCommonOptionsParam
    """Action common options"""

    output_format: Annotated[Literal["base64", "storageKey"], PropertyInfo(alias="outputFormat")]
    """⚠️ DEPRECATED: Use `options.screenshot.outputFormat` instead.

    Type of the URI. default is base64. This field will be ignored when
    `options.screenshot` is provided.
    """

    presigned_expires_in: Annotated[str, PropertyInfo(alias="presignedExpiresIn")]
    """⚠️ DEPRECATED: Use `options.screenshot.presignedExpiresIn` instead.

    Presigned url expires in. Only takes effect when outputFormat is storageKey.
    This field will be ignored when `options.screenshot` is provided.

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 30m
    """

    screenshot_delay: Annotated[str, PropertyInfo(alias="screenshotDelay")]
    """⚠️ DEPRECATED: Use `options.screenshot.delay` instead.

    This field will be ignored when `options.screenshot` is provided.

    Delay after performing the action, before taking the final screenshot.

    Execution flow:

    1. Take screenshot before action
    2. Perform the action
    3. Wait for screenshotDelay (this parameter)
    4. Take screenshot after action

    Example: '500ms' means wait 500ms after the action before capturing the final
    screenshot.

    Supported time units: ms (milliseconds), s (seconds), m (minutes), h (hours)
    Example formats: "500ms", "30s", "5m", "1h" Default: 500ms Maximum allowed: 30s
    """


class SwipeAdvancedEndSwipePath(TypedDict, total=False):
    x: Required[float]
    """Start/end x coordinate of the swipe path"""

    y: Required[float]
    """Start/end y coordinate of the swipe path"""


SwipeAdvancedEnd: TypeAlias = Union[SwipeAdvancedEndSwipePath, str]


class SwipeAdvancedStartSwipePath(TypedDict, total=False):
    x: Required[float]
    """Start/end x coordinate of the swipe path"""

    y: Required[float]
    """Start/end y coordinate of the swipe path"""


SwipeAdvancedStart: TypeAlias = Union[SwipeAdvancedStartSwipePath, str]

ActionSwipeParams: TypeAlias = Union[SwipeSimple, SwipeAdvanced]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .boxes import (
    BoxesResource,
    AsyncBoxesResource,
    BoxesResourceWithRawResponse,
    AsyncBoxesResourceWithRawResponse,
    BoxesResourceWithStreamingResponse,
    AsyncBoxesResourceWithStreamingResponse,
)
from .devices import (
    DevicesResource,
    AsyncDevicesResource,
    DevicesResourceWithRawResponse,
    AsyncDevicesResourceWithRawResponse,
    DevicesResourceWithStreamingResponse,
    AsyncDevicesResourceWithStreamingResponse,
)

__all__ = [
    "DevicesResource",
    "AsyncDevicesResource",
    "DevicesResourceWithRawResponse",
    "AsyncDevicesResourceWithRawResponse",
    "DevicesResourceWithStreamingResponse",
    "AsyncDevicesResourceWithStreamingResponse",
    "BoxesResource",
    "AsyncBoxesResource",
    "BoxesResourceWithRawResponse",
    "AsyncBoxesResourceWithRawResponse",
    "BoxesResourceWithStreamingResponse",
    "AsyncBoxesResourceWithStreamingResponse",
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
]



from .box import (
    BaseBox,
    FileOperator,
    ActionOperator,
    BrowserOperator,
    ActionScreenshot,
    LinuxBoxOperator,
    DirectoryOperator,
    AndroidAppOperator,
    AndroidBoxOperator,
    AndroidPkgOperator,
    FileSystemOperator,
)
from .sdk import GboxSDK

__all__ = [
    "GboxSDK",
    "BaseBox",
    "ActionOperator",
    "ActionScreenshot",
    "BrowserOperator",
    "FileSystemOperator",
    "FileOperator",
    "DirectoryOperator",
    "LinuxBoxOperator",
    "AndroidBoxOperator",
    "AndroidAppOperator",
    "AndroidPkgOperator",
]
